/*
 * (c) Copyright 2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.parser;

import org.databene.commons.ConfigurationError;
import org.databene.commons.StringUtil;
import org.databene.commons.xml.XMLUtil;
import org.databene.dbsanity.model.query.DefectQueryCheck;
import org.w3c.dom.Element;

/**
 * Parses the &lt;sql&gt; part of a &lt;check&gt;<br/><br/>
 * Created: 26.05.2011 11:52:23
 * @since 0.8
 * @author Volker Bergmann
 */
public class DefectQueryParser extends DbSanityXMLParser {

	public DefectQueryParser() {
		super("sql", null, null, DefectQueryCheck.class);
	}

	@Override
	public Object parse(Element element, Object[] parentPath,
			DbSanityParseContext context) {
	    Element queryElement = XMLUtil.getChildElement(element, false, false, "stmt");
	    if (queryElement == null)
	    	queryElement = element;
	    String defectQuery = StringUtil.removeEmptyLines(XMLUtil.getWholeText(queryElement));

	    // if the test definition is a SQLUnit file, require it to expect an empty result set
	    Element resultElement = XMLUtil.getChildElement(element, false, false, "result");
	    if (resultElement != null) {
	    	Element resultSetElement = XMLUtil.getChildElement(resultElement, false, false, "resultset");
	    	if (resultSetElement != null)
	    		if (!"0".equals(resultSetElement.getAttribute("rowcount")))
	    			throw new ConfigurationError("DbSanity supports only SQLUnit test which expect an empty result set");
	    }
	    DefectQueryCheck check = (DefectQueryCheck) this.parent(parentPath);
	    check.setQuery(defectQuery);
	    return defectQuery;
	}

}
