/*
 * (c) Copyright 2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.report;

import java.io.File;

import org.databene.commons.FileUtil;
import org.databene.commons.file.FilePrintStream;
import org.databene.dbsanity.model.SanityCheck;
import org.databene.dbsanity.model.SanityCheckFile;
import org.databene.dbsanity.model.SanityCheckFolder;
import org.databene.dbsanity.model.SanityCheckSuite;
import org.databene.dbsanity.model.SanityCheckVerdict;

/**
 * {@link ReportModule} which provides a digest view of all checks contained in the suite.<br/><br/>
 * Created: 12.06.2011 18:43:25
 * @since 0.8
 * @author Volker Bergmann
 */
public class DigestModule extends AbstractReportModule {

	@Override
	public int getDashboardColSpan(ReportScope scope) {
		return 1;
	}
	
	public void renderDashboardView(ReportScope scope, SanityCheckSuite suite, FilePrintStream out) {
	    startModule(out);
	    modHeader("Digest", out);
	    startModBody(out);
	    out.println("<div style='line-height:8px'>");
	    out.print("		");
	    renderIcons(suite, out);
	    out.println();
	    out.println("</div>");
        endModBody(out);
		endModule(out);
    }

	private void renderIcons(SanityCheckSuite suite, FilePrintStream out) {
		if (suite instanceof SanityCheckFolder) {
			for (SanityCheckSuite child : ((SanityCheckFolder) suite).getChildSuites().values())
				renderIcons(child, out);
		} else {
			SanityCheckFile file = (SanityCheckFile) suite;
			for (SanityCheck check : file.getChecks().values())
				renderIcon(check, out);
		}
	}

	private void renderIcon(SanityCheck check, FilePrintStream out) {
		SanityCheckVerdict v = check.getVerdict();
		File target = (v == SanityCheckVerdict.ERROR || v == SanityCheckVerdict.FAILED ? 
				check.getDefectsOrErrorPage() : check.getDocPage());
		out.print("<a href='" + FileUtil.relativePath(context.getReportRoot(), target, '/') + "'>");
		out.print("<img src='" + iconFileName(v) + "' title='" + normalize(check.getName()) + "'/>");
		out.print("</a>");
	}

	private String iconFileName(SanityCheckVerdict verdict) {
		switch (verdict) {
		case ERROR   : return "black.gif";
		case FAILED  : return "red.gif";
		case PENDING : return "blue.gif";
		case PASSED  : return "green.gif";
		default : return "gray.gif";
		}
	}

	private String normalize(String name) {
		return name.replace("'", "\"").replace(">", "&gt;").replace("<", "&lt;");
	}

}
