/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.report;

import java.io.File;

import org.databene.commons.FileUtil;
import org.databene.commons.file.FilePrintStream;
import org.databene.dbsanity.model.SanityCheck;

/**
 * {@link ReportModule} implementation which creates an HTML page for each error, 
 * displaying the reported Java stack trace.<br/><br/>
 * Created: 13.10.2010 19:31:16
 * @since 1.0
 * @author Volker Bergmann
 */
public class ErrorModule extends AbstractReportModule {
	
	@Override
    public void error(SanityCheck check, Exception e) {
		FilePrintStream out = null;
		try {
			String title = "Error Report for check '" + check.getName() + "'";
		    File file = check.getDefectsOrErrorPage();
			FileUtil.ensureDirectoryExists(file.getParentFile());
		    out = openNewFile(file, title);
			out.println(context.navBar(check.getReportFolder(), ReportUtil.docRef(check, file), "Source File"));
		    renderCheckInfo(check, out);
		    renderStackTrace(e, out);
		} catch (Exception e1) {
		    throw new RuntimeException("Unexpected error", e1);
		} finally {
			closeFile(out);
		}
    }

	public void renderStackTrace(Exception e, FilePrintStream out) {
		startModule(out);
		modHeader("Stack Trace", out);
		startModBody(out);
		out.print("			<table><tr><td><pre>");
		e.printStackTrace(out);
		out.println("		</pre></td></tr></table>");
		endModBody(out);
		endModule(out);
	}

}
