/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.report;

import org.databene.commons.MathUtil;
import org.databene.commons.file.FilePrintStream;
import org.databene.dbsanity.model.SanityCheckSuite;

/**
 * Implementation of the {@link VerdictSummaryModule} interface which requires 
 * Internet access for viewing the charts.<br/><br/>
 * Created: 05.11.2010 08:14:52
 * @since 1.0
 * @author Volker Bergmann
 */
public class OnlineVerdictSummaryModule extends VerdictSummaryModule {
	
	public void renderDashboardView(ReportScope scope, SanityCheckSuite suite, FilePrintStream out) {
	    startModule(out);
	    modHeader("Overall Summary: " + suite.getName(), out);
	    startModBody(out);
		out.println("		<table width='100%'><tr>");
		out.println("			<td align='center'>");
		if (suite.getSuccessCount() + suite.getFailureCount() + suite.getErrorCount() + suite.getSkipCount() > 0)
			out.println("				" + pieChart(suite));
		out.println("			</td>");
		out.println("			<td>");
		statsTable(suite, out);
		out.println("			</td></tr>");
		out.println("		</table>");
		endModBody(out);
		endModule(out);
	}

	private String pieChart(SanityCheckSuite suite) {
	    String data = "t:" + 
	    	suite.getSuccessCount() + "," + 
	    	suite.getFailureCount() + "," + 
	    	suite.getErrorCount() + "," +
	    	suite.getSkipCount();
	    int max = MathUtil.max(suite.getSuccessCount(), suite.getFailureCount(), suite.getErrorCount(), suite.getSkipCount());
	    return "<img src='http://chart.apis.google.com/chart" +
	    		"?chxs=0,676767,10&chxt=x" +
	    		"&chs=200x150" +
	    		"&cht=p3" +
	    		"&chco=" + ReportContext.GREEN + "," + ReportContext.RED + ",000000,B0B0B0" +
	    		"&chds=0," + max + "" +
	    		"&chd=" + data + "" +
	    		"&chdl=success|failure|error" +
	    		"&chdlp=b" +
	    		"&chp=0.067" +
	    		"&chl=+|||+" +
	    		"&chma=|0,2'" +
	    		" " +
	    		"width='200' height='150 alt='' />";
    }

}